==> typolight-2.6.7.tar.gz: typolight-2.6.7/system/modules/memberlist/languages/de/tl_member.php <==
<?php if (!defined('TL_ROOT')) die('You can not access this file directly!');

/**
 * TYPOlight webCMS
 * Copyright (C) 2005 Leo Feyer
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation, either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program. If not, please visit the Free
 * Software Foundation website at http://www.gnu.org/licenses/.
 *
 * PHP version 5
 * @copyright  Leo Feyer 2008 
 * @author     Leo Feyer 
 * @package    Memberlist 
 * @license    LGPL 
 * @filesource
 */


/**
 * Fields
 */
$GLOBALS['TL_LANG']['tl_member']['publicFields'] = array('Öffentliche Felder', 'Hier legen Sie die Felder fest, die in dem öffentlichen Profil des Mitglieds angezeigt werden.');
$GLOBALS['TL_LANG']['tl_member']['allowEmail']   = array('E-Mails erlauben', 'Bitte wählen Sie, wer dem Mitglied E-Mails senden darf.');


/**
 * References
 */
$GLOBALS['TL_LANG']['tl_member']['email_all']      = 'von jedermann';
$GLOBALS['TL_LANG']['tl_member']['email_member']   = 'von anderen Mitgliedern';
$GLOBALS['TL_LANG']['tl_member']['email_nobody']   = 'E-Mails deaktivieren';
$GLOBALS['TL_LANG']['tl_member']['profileDetails'] = 'Öffentliches Profil';

?>

==> typolight-2.7.5.tar.gz: typolight-2.7.5/system/modules/memberlist/languages/de/tl_member.php <==
<?php if (!defined('TL_ROOT')) die('You can not access this file directly!');

/**
 * TYPOlight webCMS
 * Copyright (C) 2005-2009 Leo Feyer
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation, either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program. If not, please visit the Free
 * Software Foundation website at http://www.gnu.org/licenses/.
 *
 * PHP version 5
 * @copyright  Leo Feyer 2005-2009
 * @author     Leo Feyer
 * @package    Memberlist
 * @license    LGPL
 * @filesource
 */


/**
 * Fields
 */
$GLOBALS['TL_LANG']['tl_member']['allowEmail']   = array('E-Mails erlauben', 'Hier können Sie auswählen, wer dem Benutzer E-Mails senden darf.');
$GLOBALS['TL_LANG']['tl_member']['publicFields'] = array('Öffentliche Felder', 'Hier können Sie die öffentlich sichtbaren Felder festlegen.');


/**
 * Legends
 */
$GLOBALS['TL_LANG']['tl_member']['profile_legend'] = 'Öffentliches Profil';


/**
 * References
 */
$GLOBALS['TL_LANG']['tl_member']['email_all']      = 'von jedermann';
$GLOBALS['TL_LANG']['tl_member']['email_member']   = 'von anderen Mitgliedern';
$GLOBALS['TL_LANG']['tl_member']['email_nobody']   = 'E-Mails deaktivieren';
$GLOBALS['TL_LANG']['tl_member']['profileDetails'] = 'Öffentliches Profil';

?>
